@@ -5,6 +5,7 @@ from pathlib import Path
 
 import requests
 from git import Repo
+from git.exc import InvalidGitRepositoryError
 from loguru import logger
 from pygount import SourceAnalysis
 
@@ -322,11 +323,18 @@ class OdooModule(object):
             self.module_type = "not_found"
         elif repository_name == "odoo/odoo":
             self.module_type = "odoo"
-        elif repository_name.startswith("OCA"):
-            self.module_type = "OCA"
+        elif repository_name.startswith("oca"):
+            self.module_type = "oca"
         else:
             self.module_type = "custom"
 
+    @property
+    def workload(self):
+        return sum(
+            round(module_version.workload)
+            for _, module_version in self.module_versions.items()
+        )
+
     def get_module_version(self, current_version):
         res = self.module_versions.get(current_version, False)
         return res
@@ -354,7 +362,7 @@ class OdooModule(object):
         """Search the module in all the addons path of a given version
         and return the addon path of the module, or False if not found.
         For exemple find_repository(ctx, 'web_responsive', 12.0)
-        '/PATH_TO_LOCAL_ENV/src/OCA/web'
+        '/PATH_TO_LOCAL_ENV/src/oca/web'
         """
         # Try to find the repository that contains the module
         main_path = get_odoo_env_path(ctx, current_version)
@@ -374,31 +382,64 @@ class OdooModule(object):
         """Given an addons path that contains odoo modules in a folder
         that has been checkouted via git, return a repository name with the
         following format org_name/repo_name.
-        For exemple 'OCA/web' or 'odoo/odoo'
+        For exemple 'oca/web' or 'odoo/odoo'
         """
         # TODO, make the code cleaner and more resiliant
         # for the time being, the code will fail for
         # - github url set with git+http...
         # - gitlab url
         # - if odoo code is not in a odoo folder in the repos.yml file...
-        if str(addon_path).endswith("odoo/odoo/addons") or str(
-            addon_path
-        ).endswith("openupgrade/odoo/addons"):
+        odoo_odoo_addons = (
+            "odoo/odoo/addons",
+            "odoo/openerp/addons",
+            "openupgrade/odoo/addons",
+            "openupgrade/openerp/addons",
+        )
+        odoo_addons = (
+            "odoo/addons",
+            "openupgrade/addons",
+        )
+        if str(addon_path).endswith(odoo_odoo_addons):
             path = addon_path.parent.parent
-        elif str(addon_path).endswith("odoo/addons") or str(
-            addon_path
-        ).endswith("openupgrade/addons"):
+        elif str(addon_path).endswith(odoo_addons):
             path = addon_path.parent
         else:
             path = addon_path
-        repo = Repo(str(path))
-        repository_name = repo.remotes[0].url.replace(
-            "https://github.com/", ""
+        try:
+            repo = Repo(str(path))
+        except InvalidGitRepositoryError as err:
+            logger.critical(f"{path} is not a Git Repository.")
+            raise err
+        github_url_prefixes = (
+            "https://github.com/",
+            "git@github.com:",
         )
-        if repository_name.lower() == "oca/openupgrade":
+        repository_names = []
+        for remote in repo.remotes:
+            # Standardize all repository_name to lower case
+            repository_name = remote.url.lower()
+            for github_url_prefix in github_url_prefixes:
+                repository_name = repository_name.replace(
+                    github_url_prefix, ""
+                )
+            if repository_name.endswith(".git"):
+                repository_name = repository_name[: -len(".git")]
+            repository_names.append(repository_name)
+        # find main repository_name
+        main_repository_name = next(
+            (
+                repo_name
+                for repo_name in repository_names
+                if repo_name.startswith("oca")
+            ),
+            None,
+        )
+        if not main_repository_name:
+            main_repository_name = repository_names[0]
+        if main_repository_name == "oca/openupgrade":
             return "odoo/odoo"
         else:
-            return repository_name
+            return main_repository_name
 
     def __eq__(self, other):
         if isinstance(other, str):
@@ -410,7 +451,7 @@ class OdooModule(object):
         if self.module_type != other.module_type:
             if self.module_type == "odoo":
                 return True
-            elif self.module_type == "OCA" and other.module_type in [
+            elif self.module_type == "oca" and other.module_type in [
                 "custom",
                 "not_found",
             ]:
@@ -459,12 +500,20 @@ class OdooModuleVersion(object):
         self.python_code = 0
         self.xml_code = 0
         self.javascript_code = 0
-        self.workload = 0
+        self._workload = 0
         self.analysis_file = False
         self.openupgrade_model_lines = 0
         self.openupgrade_field_lines = 0
         self.openupgrade_xml_lines = 0
 
+    @property
+    def workload(self):
+        return int(round(self._workload))
+
+    @workload.setter
+    def workload(self, value):
+        self._workload = int(round(value))
+
     def get_last_existing_version(self):
         if self.odoo_module.module_type != "not_found":
             versions = list(self.odoo_module.module_versions.values())
